@@ -1,6 +1,7 @@
 'compose_open' <- function(...) {
-   if (T & .isKnitr())
+   if (T & .isKnitr()) {
       retina0 <- 2
+   }
    else {
       retina0 <- getOption("ursaRetina")
       if (!is.numeric(retina0))
@@ -29,7 +30,8 @@
    device <- .getPrm(arglist,name="^(device|type)",valid=dtype)
    antialias <- .getPrm(arglist,name="antialias",valid=c("default","none","cleartype"))
   # font <- .getPrm(arglist,name="(font|family)",valid=ifelse(device=="windows","sans","Tahoma"))
-   font <- .getPrm(arglist,name="(^font$|family)",default=ifelse(device=="windows","sans","sans"))
+   font <- .getPrm(arglist,name="(^font$|family)"
+                  ,default=ifelse(device=="windows","sans","sans"))
    background <- .getPrm(arglist,name="(background|nodata)",default="white")
    dev <- .getPrm(arglist,name="^dev(el)*$",default=FALSE)
    verbose <- .getPrm(arglist,name="verb(ose)*",kwd="open",default=FALSE)
@@ -258,8 +260,8 @@
   #            ,antialias=antialias,family=font))
   # }
    else {
-      if (device=="default")
-         device <- "cairo"
+     # if (device=="default")
+     #    device <- "cairo"
       if ((device %in% c("cairo","cairo-png"))&&(!capabilities("cairo"))) {
          if (.Platform$OS.type=="windows")
             device <- "windows"
@@ -290,7 +292,9 @@
           ,ursaPngPlot=!dev,ursaPngPaperScale=paperScale 
           ,ursaPngFamily=font,ursaPngWaitBeforeRemove=wait
           ,ursaPngDevice=device,ursaPngShadow=""
-          ,ursaPngBackground=background,ursaPngPanel="",ursaPngSkip=FALSE)
+          ,ursaPngBackground=background,ursaPngPanel="",ursaPngSkip=FALSE
+          ,ursaPngRetina=retina
+          ,ursaPngPointsize=pointsize,ursaPngComposeGrid=session_grid())
   # if (.isKnitr()) {
   #   # if (knitr::opts_knit$get(""))
   #    fileout <- paste0("file:///",fileout)
