@@ -2,8 +2,11 @@
    arglist <- list(...)
    opR <- options(ursaPngAuto=TRUE)
    isWeb <- getOption("ursaPngWebCartography")
+   ann <- getOption("ursaPngCopyright")
+   ann <- ((is.character(ann))&&(nchar(ann)))
+   ann <- ((ann)&&(!.getPrm(arglist,name="coast",default=FALSE)))
    isWeb <- (is.logical(isWeb)&&(isWeb))
-   if (isWeb)
+   if (isWeb & !ann)
       do.call("panel_coastline",arglist)
    ind <- .grep("decor",names(arglist))
    if (!length(ind))
